handle a submission in the wrong format
=======================================

If a file is checked that is not an `ipynb` file then the checker will write the
following to the feedback file::

    "Your notebook file was not in the correct format and could not be read"

Note than when batch checking, this will not stop the checker from checking the
other files.
